Enum tcl::interpreter::AppendStyle
[−]
[src]
pub enum AppendStyle {
Replace,
Append,
ReplaceAsList,
AppendAsList,
}When setting a variable, how should we handle existing values
Variants
ReplaceIf the variable exists, replace it
AppendIf the variable exists, append it
ReplaceAsListSet the variable to a single-element list
AppendAsListIf the variable exists, append a list element to it